@@ -1,6 +1,6 @@
 package SPVM::MIME::Base64;
 
-our $VERSION = "1.002";
+our $VERSION = "1.003";
 
 1;
 
@@ -10,7 +10,7 @@ SPVM::MIME::Base64 - Base64 Encoding/Decoding
 
 =head1 Description
 
-The MIME::Base64 class of L<SPVM> has methods for L<Base64|https://en.wikipedia.org/wiki/Base64> encoding/decoding.
+MIME::Base64 class in L<SPVM> has methods for L<Base64|https://en.wikipedia.org/wiki/Base64> encoding/decoding.
 
 =head1 Usage
 
